/*
 * StringHandler.java
 *
 * Created on 12 May 2009
 *
 * Version 1.1
 *
 * Copyright (c) Kieran Greer
 *
 * Author: Kieran Greer
 */

package org.jlog2.util;


import java.util.*;


/**
 * This class provides additional String processing functionality over
 * what the CDC Java package 1.0 provides.
 * @author Kieran Greer
 */
public class StringHandler
{
    /**
     * Return true if the String s1 contains the String s2.
     * @param s1 the first String.
     * @param s2 the second String.
     * @return true if s1 contains s2 as part of its sequence of characters.
     */
    public static boolean contains(String s1, String s2)
    {
        return (s1.indexOf(s2) >= 0);
    }
    
    /**
     * Return true if the String s1 contains the String s2 ignoring case.
     * @param s1 the first String.
     * @param s2 the second String.
     * @return true if s1 contains s2 as part of its sequence of characters.
     */
    public static boolean containsIgnoreCase(String s1, String s2)
    {
        s1 = s1.toLowerCase();
        s2 = s2.toLowerCase();
        return (s1.indexOf(s2) >= 0);
    }

    /**
     * Replace the first occurrence of s2 in s1 with the replacement text.
     * @param s1 the String to change.
     * @param s2 the text to remove.
     * @param replace the text to replace s2 with.
     * @return the s1 String with the first occurrence of s2 replaced with replace.
     */
    public static String replaceFirst(String s1, String s2, String replace)
    {
        int index;                          //index
        String replacedStr;                 //String with replaced text

        replacedStr = "";
        index = s1.indexOf(s2);

        if (index >= 0)
        {
            replacedStr = s1.substring(0, index);
            replacedStr += replace;
            replacedStr += s1.substring(index + s2.length());
        }
        else
        {
            replacedStr = s1;
        }

        return replacedStr;
    }

    /**
     * Replace all occurrences of s2 in s1 with the replacement text.
     * @param s1 the String to change.
     * @param s2 the text to remove.
     * @param replace the text to replace s2 with.
     * @return the s1 String with all occurrences of s2 replaced with replace.
     */
    public static String replaceAll(String s1, String s2, String replace)
    {
        int index;                          //index
        String replacedStr;                 //String with replaced text
        String remainingStr;                //String with remaining text

        replacedStr = "";
        if (s1 != null)
        {
            remainingStr = s1;
            index = remainingStr.indexOf(s2);

            if (index >= 0)
            {
                while (index >= 0)
                {
                    replacedStr = remainingStr.substring(0, index);
                    replacedStr += replace;
                    index += s2.length();
                    replacedStr += remainingStr.substring(index);

                    remainingStr = replacedStr;
                    index = (index - s2.length() + replace.length());
                    index = remainingStr.indexOf(s2, index);
                }
            }
            else
            {
                replacedStr = s1;
            }
        }
        else
        {
            replacedStr = s1;
        }

        return replacedStr;
    }

    /**
     * Tokenize the string based on the separator and return the tokens.
     * @param s1 the string to tokenize.
     * @param separator the character sequence to separate tokens.
     * @param includeSeparator if true include separator string as tokens.
     * @return the list of strings tokenized by the separator.
     */
    public static Vector tokenize(String s1, String separator, boolean includeSeparator)
    {
        int index;                          //index
        String nextToken;                   //next token
        String remainingStr;                //String with remaining text
        Vector tokens;                      //list of tokens

        tokens = new Vector();
        if (s1 != null)
        {
            remainingStr = s1;
            index = remainingStr.indexOf(separator);

            if (index >= 0)
            {
                while (index >= 0)
                {
                    nextToken = remainingStr.substring(0, index);
                    tokens.addElement(nextToken);
                    if (includeSeparator) tokens.addElement(separator);

                    index += separator.length();
                    remainingStr = remainingStr.substring(index, remainingStr.length());

                    if (remainingStr.length() > 0)
                        index = remainingStr.indexOf(separator);
                    else
                        index = -1;
                }

                if (remainingStr.length() > 0)
                {
                    if (!remainingStr.equals(separator)) tokens.addElement(remainingStr);
                    else if (includeSeparator) tokens.addElement(remainingStr);
                }
            }
            else
            {
                tokens.addElement(s1);
            }
        }

        return tokens;
    }
}
